@@ -1,9 +1,26 @@
 # -------------------------------------------------------------------------------------
 # MKDoc
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver (jhiver@mkdoc.com).
+# Author : Jean-Michel Hiver.
 # Copyright : (c) MKDoc Holdings Ltd, 2003
 #
+# This file is part of MKDoc. 
+# 
+# MKDoc is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+# 
+# MKDoc is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with MKDoc; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+#
 # This is the top-level module of the MKDoc web-based document management system.
 # It takes care of variable initialization, then triggers each plugin module in the
 # order defined in the plugin config file given (see process()), until one of the 
@@ -46,8 +63,14 @@ sub process
 	my $error_p = new flo::plugin::Error ( status => '400 Bad Request' );
 	return $error_p->run();
     };
-    
-    main();
+
+    # hack to make Petal temp files on a per-site basis
+    {
+        my $tmp_dir = $Petal::Cache::Disk::TMP;
+        my $dir     = MKDoc::Config->CACHE_DIR() . '/petal';
+        local $Petal::Cache::Disk::TMP = do { (-e $dir && -d $dir) ? $dir : undef } || $tmp_dir;
+        main();
+    }
 }
 
 
