@@ -2,11 +2,24 @@
 # MKDoc::CGI
 # -------------------------------------------------------------------------------------
 #
-#       Author : Jean-Michel Hiver (jhiver@mkdoc.com).
-#    Copyright : (c) Jean-Michel Hiver, 2002.
+#       Author : Jean-Michel Hiver.
+#    Copyright : (c) MKDoc Holdings Ltd., 2002.
 # 
-#      Unauthorized modification, use, reuse, distribution or redistribution
-#      of this module is stricly forbidden.
+# This file is part of MKDoc. 
+# 
+# MKDoc is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+# 
+# MKDoc is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with MKDoc; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #    Description:
 #
@@ -30,7 +43,7 @@ sub get
     my $class = shift;
     $class = ref $class || $class;
 
-    $::MKD_CGI ||= $class->new(); 
+    $::MKD_CGI ||= $class->new();
     return $::MKD_CGI;
 }
 
@@ -42,15 +55,15 @@ sub get
 ##
 sub self_url
 {
-    my $self = shift;    
+    my $self = shift;
     my $url = $self->url ( -relative  => 0,
 			   -path_info => 1,
 			   -query     => 1 );
     
     # remove the blah:80 like URIs
-    $url =~ s/(.*?\:\/\/(?:.*?\@)?)(.*):80(?!\d)(.*)/$1$2$3/
-        if ($url =~ /(.*?\:\/\/(?:.*?\@)?)(.*):80(?!\d)(.*)/);
-    
+    $url =~ s/(.*?\:\/\/(?:.*?\@)?)(.*):80\d*(?!\d)(.*)/$1$2$3/
+        if ($url =~ /(.*?\:\/\/(?:.*?\@)?)(.*):80\d*(?!\d)(.*)/);
+
     return $url;
 }
 
@@ -62,6 +75,13 @@ sub delete
 }
 
 
+sub delete_all_fast
+{
+    my $self = shift;
+    $self->{'.parameters'} = [];
+}
+
+
 sub is_upload
 {
     my ($self, $param_name) = @_;
@@ -71,59 +91,54 @@ sub is_upload
 }
 
 
-# WARNING! For some reason, the incoming UTF-8 strings
-# are not internally marked up as UTF-8 when they should... 
 sub param
 {
-    my $self = shift;
-    return $self->SUPER::param (@_) if ($self->is_upload (@_));
+    my $self  = shift;
+    my $key   = shift || return $self->SUPER::param ();
+
+    $self->is_upload ($key => @_) and return $self->SUPER::param ($key => @_);
+    @_                            and return $self->SUPER::param ($key => @_);
+
+    my @res = $self->SUPER::param ($key);
+    @res = map {
+        (defined $_) ? do {
+            my $res = $_;
+            my $octets = $_;
+            my $string = Encode::decode_utf8 ($octets, Encode::FB_PERLQQ);
+            $string;
+        } : undef
+    } @res;
+
+=cut
+
+    @_ and do {
+        $self->{'.params_cached__'} ||= {};
+        delete $self->{'.params_cached__'}->{$key};
+        return $self->SUPER::param ($key => @_);
+    };
     
-    if (wantarray)
-    {
-	my @res = $self->SUPER::param (@_);
-	foreach my $element (@res)
-	{
-	    if (defined $element)
-	    {
-		my $tmp = Encode::decode ('UTF-8', $element);
-		if (defined $tmp)
-		{
-		    $element = $tmp;
-		}
-	    }
-	}
-	return @res;
-    }
-    else
-    {
-	my $res = $self->SUPER::param (@_);
-	if (ref $res and ref $res eq 'ARRAY')
-	{
-	    foreach my $element (@{$res})
-	    {
-		if (defined $_)
-		{
-		    my $tmp = Encode::decode ('UTF-8', $element);
-		    if (defined $tmp)
-		    {
-			$element = $tmp;
-			Encode::_utf8_on ($element);
-		    }
-		}
-	    }
-	}
-	else
-	{
-	    my $tmp = Encode::decode ('UTF-8', $res);
-	    if (defined $tmp)
-	    {
-		$res = $tmp;
-		Encode::_utf8_on ($res);
-	    }
-	}
-	
-	return $res;
-    }
+    $self->{'.params_cached__'} ||= {};
+    $self->{'.params_cached__'}->{$key} ||= do {
+        my @res = $self->SUPER::param ($key);
+        @res = map {
+            my $octets = $_;
+            my $string = Encode::decode_utf8 ($octets);
+            $string;
+        } @res;
+
+        \@res;
+    };
+
+    use Data::Dumper;
+    warn Dumper ( $self->{'.params_cached__'}->{$key} );
+
+    my @res = @{ $self->{'.params_cached__'}->{$key} };
+
+=cut
+
+    @res == 0 and return;
+    @res == 1 and return shift @res;
+    return wantarray ? @res : \@res;
 }
 
 
