@@ -1,8 +1,25 @@
 # -------------------------------------------------------------------------------------
 # flo::Component
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver <jhiver@mkdoc.com>
+# Author : Jean-Michel Hiver
 # Copyright : (c) MKDoc Holdings Ltd, 2002
+#
+# This file is part of MKDoc. 
+# 
+# MKDoc is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+# 
+# MKDoc is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with MKDoc; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
 # 
 # Discussion content component. Should let the user add hyperlinks to pages
 # -------------------------------------------------------------------------------------
@@ -504,13 +521,14 @@ sub mkdoc_uri
 {
     my $self = shift;
     my $cgix = flo::Standard::cgi()->new;
-    $cgix->delete ($_) for ($cgix->param);
+    $cgix->delete_all_fast();
     $cgix->path_info ( $self->path );
     while (@_)
     {
 	my ($key, $val) = (shift, shift);
 	$cgix->param ($key, $val);
     }
+
     return $cgix->self_url;
 }
 
@@ -528,6 +546,20 @@ sub name
 }
 
 
+##
+# $self->name_is ($stuff);
+# -----------------------------
+# Returns TRUE if this component's name is $stuff,
+# FALSE otherwise.
+##
+sub name_is
+{
+    my $self = shift;
+    my $name = shift || '';
+    return lc ($self->name()) eq lc ($name);
+}
+
+
 ##
 # $self->generate_xml;
 # --------------------
@@ -562,17 +594,23 @@ sub parse_xml
     my $self = shift;
     eval {
         my $xml  = shift;
+        $xml = Encode::encode_utf8 ($xml);
+
         my $obj  = $self->xml_cache_get ($xml) || do {
             my $res = MKDoc::XML::Dumper->xml2perl ($xml);
             $self->xml_cache_set ($xml, $res);
             $res;
         };
 
-        $self->{$_} = $obj->{$_} for (keys %{$obj});
+        for (keys %{$obj})
+        {
+            $self->{$_} = Encode::decode_utf8  ($obj->{$_} );
+        }
+
         $self->__on_load() if ($self->can ('__on_load'));
     };
-    # $@ and warn $@;
-    # Carp::cluck ($@);
+
+    $@ and warn "== $@ ==";
 }
 
 
