@@ -1,9 +1,26 @@
 # -------------------------------------------------------------------------------------
 # flo::Record::Document
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver (jhiver@mkdoc.com).
+# Author : Jean-Michel Hiver.
 # Copyright : (c) MKDoc Holdings Ltd, 2003.
 #
+# This file is part of MKDoc. 
+# 
+# MKDoc is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+# 
+# MKDoc is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with MKDoc; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+#
 # This class models MKDoc document objects, and holds methods related to document
 # hierarchy and metadata validation.
 # -------------------------------------------------------------------------------------
@@ -1435,15 +1452,29 @@ sub available_langs
 
 sub used_langs
 {
-    my $class          = shift;
-    my $document_table = flo::Standard::table ('Document');
-    my $query          = $document_table->select (
-	distinct => 1,
-	cols     => 'Lang',
-       );
+    my $class = shift;
+    my $sql   = <<'EOF';
+SELECT DISTINCT (Lang)
+FROM Document
+WHERE Name NOT LIKE 'deleted-____-__-__-__-__-__'  AND
+      Name NOT LIKE 'modified-____-__-__-__-__-__' AND
+      Name NOT LIKE 'private-%'                    AND
+      Name NOT LIKE 'hidden-%'
+EOF
     
-    my @langs = map { $_->{Lang} } $query->fetch_all;
-    return @langs;
+    my $dbh = lib::sql::DBH->get();
+    $dbh->prepare ($sql);
+
+    my @res = ();
+
+    my $sth = $dbh->prepare ($sql);
+    $sth->execute();
+    while (my $array_ref = $sth->fetchrow_arrayref())
+    {
+        push @res, $array_ref->[0];
+    }
+
+    return wantarray ? @res : \@res;
 }
 
 
@@ -1594,10 +1625,8 @@ sub set_sort_method
 sub validate_sort_method
 {
     my $self = shift;
-    return 1 if ($self->sort_method);
-    
-    new MKDoc::Ouch ( 'document/sort' );
-    return 0;
+    $self->sort_method() || $self->set_sort_method (SORT_METHOD_TITLE);
+    return 1;
 }
 
 
