@@ -1,8 +1,25 @@
 # -------------------------------------------------------------------------------------
 # flo::editor::Headlines
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver <jhiver@mkdoc.com>.
+# Author : Jean-Michel Hiver.
 # Copyright : (c) MKDoc Holdings Ltd, 2003
+#
+# This file is part of MKDoc. 
+# 
+# MKDoc is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+# 
+# MKDoc is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with MKDoc; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
 # -------------------------------------------------------------------------------------
 package flo::editor::Headlines;
 use flo::Record::Editor;
@@ -12,6 +29,7 @@ use flo::Editor;
 use flo::Standard;
 use MKDoc::CGI;
 use MKDoc::Util::Text2HTML;
+use flo::RedirectManager;
 use strict;
 use utf8;
 
@@ -132,7 +150,13 @@ sub set_title
 sub from_path
 {
     my $self = shift;
-    return $self->{from_path};
+    my $path = $self->{from_path};
+    
+    my $doc_t = flo::Standard::table ('Document');
+    $doc_t->get ($path) or do { $path = flo::RedirectManager->translate_path ($path) || $path };
+    $self->{from_path} = $path;    
+    
+    return $path;
 }
 
 
