@@ -1,8 +1,25 @@
 # -------------------------------------------------------------------------------------
 # flo::editor::Html
 # -------------------------------------------------------------------------------------
-# Author : Jean-Michel Hiver <jhiver@mkdoc.com>.
+# Author : Jean-Michel Hiver.
 # Copyright : (c) MKDoc Holdings Ltd, 2003
+#
+# This file is part of MKDoc. 
+# 
+# MKDoc is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+# 
+# MKDoc is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# You should have received a copy of the GNU General Public License
+# along with MKDoc; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
 # -------------------------------------------------------------------------------------
 package flo::editor::Html;
 use flo::Standard;
@@ -86,7 +103,7 @@ sub parse_xml
 }
 
 
-sub as_xhtml { return "<div>" . shift()->html() . "</div>" }
+sub as_xhtml { return "<div class=\"html\">" . shift()->html() . "</div>" }
 
 
 ##
@@ -178,7 +195,3 @@ sub html_tidy
 
 
 1;
-
-
-
-
